@@ -4,7 +4,7 @@ package JSON::Schema::Modern::Annotation;
 # vim: set ts=8 sts=2 sw=2 tw=100 et :
 # ABSTRACT: Contains a single annotation from a JSON Schema evaluation
 
-our $VERSION = '0.583';
+our $VERSION = '0.584';
 
 use 5.020;
 use Moo;
@@ -12,6 +12,7 @@ with 'JSON::Schema::Modern::ResultNode';
 use strictures 2;
 use stable 0.031 'postderef';
 use experimental 'signatures';
+no autovivification warn => qw(fetch store exists delete);
 use if "$]" >= 5.022, experimental => 're_strict';
 no if "$]" >= 5.031009, feature => 'indirect';
 no if "$]" >= 5.033001, feature => 'multidimensional';
@@ -41,6 +42,8 @@ around BUILDARGS => sub ($orig, $class, @args) {
   return $args;
 };
 
+sub __thing { 'annotation' }
+
 1;
 
 __END__
@@ -57,7 +60,7 @@ JSON::Schema::Modern::Annotation - Contains a single annotation from a JSON Sche
 
 =head1 VERSION
 
-version 0.583
+version 0.584
 
 =head1 SYNOPSIS
 
