@@ -4,13 +4,14 @@ package JSON::Schema::Modern::ResultNode;
 # vim: set ts=8 sts=2 sw=2 tw=100 et :
 # ABSTRACT: Common code for nodes of a JSON::Schema::Modern::Result
 
-our $VERSION = '0.583';
+our $VERSION = '0.584';
 
 use 5.020;
 use Moo::Role;
 use strictures 2;
 use stable 0.031 'postderef';
 use experimental 'signatures';
+no autovivification warn => qw(fetch store exists delete);
 use if "$]" >= 5.022, experimental => 're_strict';
 no if "$]" >= 5.031009, feature => 'indirect';
 no if "$]" >= 5.033001, feature => 'multidimensional';
@@ -53,7 +54,7 @@ has absolute_keyword_location => (
 
       undef $uri if $uri eq '' and $self->{keyword_location} eq ''
         or ($uri->fragment // '') eq $self->{keyword_location} and $uri->clone->fragment(undef) eq '';
-      return $uri if defined $uri;
+      return $uri;
     }
 
     return;
@@ -79,7 +80,8 @@ sub BUILD ($self, $args) {
 }
 
 sub TO_JSON ($self) {
-  my $thing = lcfirst((reverse split /::/, ref $self)[0]);
+  my $thing = $self->__thing;  # annotation or error
+
   return +{
     # note that locations are JSON pointers, not uri fragments!
     instanceLocation => $self->instance_location,
@@ -115,7 +117,7 @@ JSON::Schema::Modern::ResultNode - Common code for nodes of a JSON::Schema::Mode
 
 =head1 VERSION
 
-version 0.583
+version 0.584
 
 =head1 SYNOPSIS
 
