@@ -4,13 +4,14 @@ package JSON::Schema::Modern::Vocabulary;
 # vim: set ts=8 sts=2 sw=2 tw=100 et :
 # ABSTRACT: Base role for JSON Schema vocabulary classes
 
-our $VERSION = '0.583';
+our $VERSION = '0.584';
 
 use 5.020;
 use Moo::Role;
 use strictures 2;
 use stable 0.031 'postderef';
 use experimental 'signatures';
+no autovivification warn => qw(fetch store exists delete);
 use if "$]" >= 5.022, experimental => 're_strict';
 no if "$]" >= 5.031009, feature => 'indirect';
 no if "$]" >= 5.033001, feature => 'multidimensional';
@@ -81,6 +82,7 @@ sub eval_subschema_at_uri ($class, $data, $schema, $state, $uri) {
     +{
       $schema_info->{configs}->%*,
       %$state,
+      # keyword is assumed to be json pointer-encoded (if a suffix path is needed), so we just concat
       traversed_schema_path => $state->{traversed_schema_path}.$state->{schema_path}.'/'.$state->{keyword},
       initial_schema_uri => $schema_info->{canonical_uri},
       document => $schema_info->{document},
@@ -105,7 +107,7 @@ JSON::Schema::Modern::Vocabulary - Base role for JSON Schema vocabulary classes
 
 =head1 VERSION
 
-version 0.583
+version 0.584
 
 =head1 SYNOPSIS
 
