@@ -73,6 +73,8 @@ sub acceptance_tests (%options) {
         if not $ENV{NO_SHORT_CIRCUIT}
           and ($result xor $result_short);
 
+      my $in_todo;
+
       # if any errors contain an exception, generate a warning so we can be sure
       # to count that as a failure (an exception would be caught and perhaps TODO'd).
       # (This might change if tests are added that are expected to produce exceptions.)
@@ -80,7 +82,8 @@ sub acceptance_tests (%options) {
         print STDERR 'evaluation generated an exception: '.$_->dump
           foreach
             grep +($_->{error} =~ /^EXCEPTION/
-                && $_->{error} !~ /(max|min)imum value is not a number$/),  # optional/bignum.json
+                && $_->{error} !~ /(max|min)imum value is not a number$/)   # optional/bignum.json
+                && !($in_todo //= grep $_->{todo}, Test2::API::test2_stack->top->{_pre_filters}->@*),
               $r->errors;
       }
 
